@@ -4,7 +4,7 @@ c = zerorpc.Client()
 c.connect('tcp://127.0.0.1:4242')
 
 def addSimJob(job):
-    c.addSimJob(job)
+    return c.addSimJob(job)
 
 def echo(data):
-    c.echo(data)
+    return c.echo(data)
